.learners-panel{width:750px;display:inline-block}.learners-panel .learners-table{margin-bottom:10px;width:100%}.forms-panel{vertical-align:top;width:350px;margin-left:20px}#id_course_mode{width:150px}.forms-panel{width:750px;display:inline-block;margin-bottom:10px}.forms-panel .helptext{display:block;font-size:.8em;color:#bbb}